Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(400)

Unified Diff: third_party/WebKit/public/platform/WebMediaPlayer.h

Issue 2791813003: Fix broken draw/upload paths from videos to 2D canvas and WebGL. (Closed)
Patch Set: Disable GPU-GPU copies to floating-point textures on Android. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/platform/WebMediaPlayer.h
diff --git a/third_party/WebKit/public/platform/WebMediaPlayer.h b/third_party/WebKit/public/platform/WebMediaPlayer.h
index 959631b40cca8fcf31cc8f83b13e9706a7a018e9..4f17e2e0172cee478408227f14c4209c80e7557d 100644
--- a/third_party/WebKit/public/platform/WebMediaPlayer.h
+++ b/third_party/WebKit/public/platform/WebMediaPlayer.h
@@ -177,19 +177,20 @@ class WebMediaPlayer {
// TODO(kbr): remove non-|target| version. crbug.com/349871
//
// Do a GPU-GPU texture copy of the natural size of the current
// video frame to |texture|. Caller is responsible for allocating
// |texture| with the appropriate size. If the copy is impossible or
// fails, it returns false.
virtual bool CopyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
unsigned texture,
+ unsigned internal_format,
+ unsigned format,
+ unsigned type,
bool premultiply_alpha,
bool flip_y) {
return false;
}
- // TODO(kbr): when updating calling code to use this, remove the
- // |internalFormat| and |type| parameters. crbug.com/349871
// Do a GPU-GPU textures copy. If the copy is impossible or fails, it returns
// false.
virtual bool CopyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
@@ -177,19 +177,20 @@ class WebMediaPlayer {
// TODO(kbr): remove non-|target| version. crbug.com/349871
//
- // Do a GPU-GPU texture copy of the natural size of the current
- // video frame to |texture|. Caller is responsible for allocating
- // |texture| with the appropriate size. If the copy is impossible or
- // fails, it returns false.
+ // Do a GPU-GPU texture copy of the current video frame to |texture|,
+ // reallocating |texture| at the appropriate size with given internal
+ // format, format, and type if necessary. If the copy is impossible
+ // or fails, it returns false.
virtual bool CopyVideoTextureToPlatformTexture(gpu::gles2::GLES2Interface*,
unsigned texture,
« no previous file with comments | « third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.cpp ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698